@@ -480,7 +480,7 @@ public class CompositeArtifactRepository extends AbstractArtifactRepository impl
 					jarFile.createNewFile();
 				}
 				os = new JarOutputStream(new FileOutputStream(jarFile));
-				((JarOutputStream) os).putNextEntry(new JarEntry(new Path(artifactsFile.getAbsolutePath()).lastSegment()));
+				((JarOutputStream) os).putNextEntry(new JarEntry(IPath.fromOSString(artifactsFile.getAbsolutePath()).lastSegment()));
 			}
 			super.setProperty(IRepository.PROP_TIMESTAMP, Long.toString(System.currentTimeMillis()));
 			new CompositeRepositoryIO().write(toState(), os, PI_REPOSITORY_TYPE);
