@@ -88,7 +88,7 @@ public class SimpleArtifactRepositoryIO {
 		try {
 			try {
 				bufferedInput = new BufferedInputStream(input);
-				Parser repositoryParser = new Parser(Activator.ID);
+				Parser repositoryParser = new Parser(Activator.ID, location);
 				repositoryParser.setErrorContext(location.toURL().toExternalForm());
 				IStatus result = null;
 				boolean lock = false;
@@ -299,9 +299,11 @@ public class SimpleArtifactRepositoryIO {
 	private class Parser extends XMLParser implements XMLConstants {
 
 		private SimpleArtifactRepository theRepository = null;
+		private URI uri;
 
-		public Parser(String bundleId) {
+		public Parser(String bundleId, URI uri) {
 			super(bundleId);
+			this.uri = uri;
 		}
 
 		public synchronized void parse(InputStream stream) throws IOException {
@@ -310,7 +312,7 @@ public class SimpleArtifactRepositoryIO {
 				// TODO: currently not caching the parser since we make no assumptions
 				//		 or restrictions on concurrent parsing
 				XMLReader reader = getParser().getXMLReader();
-				RepositoryHandler repositoryHandler = new RepositoryHandler();
+				RepositoryHandler repositoryHandler = new RepositoryHandler(uri);
 				reader.setContentHandler(new RepositoryDocHandler(REPOSITORY_ELEMENT, repositoryHandler));
 				reader.parse(new InputSource(stream));
 				if (isValidXML()) {
@@ -372,9 +374,11 @@ public class SimpleArtifactRepositoryIO {
 			private ArtifactsHandler artifactsHandler = null;
 
 			private SimpleArtifactRepository repository = null;
+			private URI location;
 
-			public RepositoryHandler() {
+			public RepositoryHandler(URI uri) {
 				super();
+				this.location = uri;
 			}
 
 			public SimpleArtifactRepository getRepository() {
@@ -422,7 +426,7 @@ public class SimpleArtifactRepositoryIO {
 					Set<SimpleArtifactDescriptor> artifacts = (artifactsHandler == null ? new HashSet<>(0) //
 							: artifactsHandler.getArtifacts());
 					repository = new SimpleArtifactRepository(agent, attrValues[0], attrValues[1], attrValues[2], attrValues[3], //
-							attrValues[4], artifacts, mappingRules, properties);
+							location, attrValues[4], artifacts, mappingRules, properties);
 				}
 			}
 		}
