@@ -82,9 +82,6 @@ public class CacheManager {
 	private static final String JAR_EXTENSION = ".jar"; //$NON-NLS-1$
 	private static final String XML_EXTENSION = ".xml"; //$NON-NLS-1$
 
-	/** Allows to mute "Using unsafe http transport" warnings */
-	private static final boolean SKIP_REPOSITORY_PROTOCOL_CHECK = Boolean.getBoolean("p2.skipRepositoryProtocolCheck"); //$NON-NLS-1$
-
 	private final HashSet<String> knownPrefixes = new HashSet<>(5);
 
 	/**
@@ -98,7 +95,6 @@ public class CacheManager {
 		if (!isURL(remoteFile)) {
 			throw new ProvisionException(new Status(IStatus.ERROR, Activator.ID, ProvisionException.REPOSITORY_NOT_FOUND, NLS.bind(Messages.CacheManager_CannotLoadNonUrlLocation, remoteFile), null));
 		}
-		checkLocationIsSecure(remoteFile);
 
 		SubMonitor submonitor = SubMonitor.convert(monitor, 1000);
 		try {
@@ -117,20 +113,23 @@ public class CacheManager {
 				// it is not meaningful to continue - the credentials are for the server
 				// do not pass the exception - it gives no additional meaningful user information
 				throw new ProvisionException(new Status(IStatus.ERROR, Activator.ID, ProvisionException.REPOSITORY_FAILED_AUTHENTICATION, NLS.bind(Messages.CacheManager_AuthenticationFaileFor_0, remoteFile), null));
+			} catch (FileNotFoundException e) {
+				throw new FileNotFoundException(NLS.bind(Messages.CacheManager_Repository_not_found, remoteFile));
 			} catch (CoreException e) {
-				// give up on a timeout - if we did not get a 404 on the jar, we will just prolong the pain
-				// by (almost certainly) also timing out on the xml.
-				if (e.getStatus() != null && e.getStatus().getException() != null) {
-					Throwable ex = e.getStatus().getException();
+				IStatus status = e.getStatus();
+				if (status == null)
+					throw new ProvisionException(
+							new Status(IStatus.ERROR, Activator.ID, ProvisionException.REPOSITORY_NOT_FOUND,
+									NLS.bind(Messages.CacheManager_FailedCommunicationWithRepo_0, remoteFile), e));
+				else if (status.getException() instanceof FileNotFoundException)
+					throw new ProvisionException(new Status(IStatus.ERROR, Activator.ID,
+							ProvisionException.REPOSITORY_NOT_FOUND, status.getMessage(), status.getException()));
+				else if (status.getException() != null) {
+					Throwable ex = status.getException();
 					if (ex.getClass() == java.net.SocketTimeoutException.class)
 						throw new ProvisionException(new Status(IStatus.ERROR, Activator.ID, ProvisionException.REPOSITORY_FAILED_READ, NLS.bind(Messages.CacheManager_FailedCommunicationWithRepo_0, remoteFile), ex));
 				}
-			} catch (OperationCanceledException e) {
-				// must pass this on
-				throw e;
-			} catch (Exception e) {
-				// not ideal, just skip the jar on error, and try the xml instead - report errors for
-				// the xml.
+				throw new ProvisionException(status);
 			}
 
 			stale = lastModifiedRemote != lastModified;
@@ -165,7 +164,6 @@ public class CacheManager {
 		if (!isURL(repositoryLocation)) {
 			throw new ProvisionException(new Status(IStatus.ERROR, Activator.ID, ProvisionException.REPOSITORY_NOT_FOUND, NLS.bind(Messages.CacheManager_CannotLoadNonUrlLocation, repositoryLocation), null));
 		}
-		checkLocationIsSecure(repositoryLocation);
 		SubMonitor submonitor = SubMonitor.convert(monitor, 1000);
 		try {
 			knownPrefixes.add(prefix);
@@ -272,15 +270,6 @@ public class CacheManager {
 		}
 	}
 
-	private void checkLocationIsSecure(URI repositoryLocation) {
-		if (SKIP_REPOSITORY_PROTOCOL_CHECK) {
-			return;
-		}
-		if ("http".equals(repositoryLocation.getScheme())) { //$NON-NLS-1$
-			LogHelper.log(new Status(IStatus.WARNING, Activator.ID, NLS.bind(Messages.unsafeHttp, repositoryLocation)));
-		}
-	}
-
 	private long getLastModified(URI location, IProgressMonitor monitor) throws AuthenticationFailedException, FileNotFoundException, CoreException {
 		CoreException exception = null;
 		long lastModifiedRemote = -1L;
