@@ -385,13 +385,16 @@ public class DefaultPGPPublicKeyService extends PGPPublicKeyService {
 							return signature.getCreationTime();
 						}
 					} catch (PGPException e) {
-						//$FALL-THROUGH$
+						// https://bugs.eclipse.org/bugs/show_bug.cgi?id=581453
+						// When something goes wrong, assume that it's revoked.
+						return new Date(0);
 					}
 					break;
 				}
 				}
 			}
 		}
+
 		return null;
 	}
 
