@@ -28,6 +28,7 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipOutputStream;
+
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.NullProgressMonitor;
 import org.eclipse.core.runtime.URIUtil;
@@ -57,7 +58,6 @@ import org.eclipse.osgi.util.NLS;
 public class MirrorTaskTest extends AbstractAntProvisioningTest {
 	private static final String DOWNLOAD_CHECKSUM = IArtifactDescriptor.DOWNLOAD_CHECKSUM + ".sha-256";
 	private static final String MIRROR_TASK = "p2.mirror";
-	private static final String MIRROR_ARTIFACTS_TASK = "p2.artifact.mirror";
 	private URI destinationRepo;
 	private URI artifactRepo, sliceArtifactRepo, sliceRepo, sourceRepo2, zipRepo;
 
@@ -66,7 +66,7 @@ public class MirrorTaskTest extends AbstractAntProvisioningTest {
 		super.setUp();
 		// Get a random location to create a repository
 		destinationRepo = (new File(getTestFolder(getName()), "destinationRepo")).toURI();
-		artifactRepo = getTestData("error loading data", "testData/mirror/mirrorPackedRepo").toURI();
+		artifactRepo = getTestData("error loading data", "testData/mirror/mirrorRepo").toURI();
 		sourceRepo2 = getTestData("error loading data", "testData/mirror/mirrorSourceRepo2").toURI();
 		sliceRepo = getTestData("error loading data", "testData/permissiveSlicer").toURI();
 		sliceArtifactRepo = getTestData("error loading data", "testData/testRepos/updateSite").toURI();
@@ -709,19 +709,6 @@ public class MirrorTaskTest extends AbstractAntProvisioningTest {
 		}
 	}
 
-	public void testMirrorPackedRepo() {
-		AntTaskElement mirror = new AntTaskElement(MIRROR_ARTIFACTS_TASK);
-		mirror.addAttribute("destination", URIUtil.toUnencodedString(destinationRepo));
-		mirror.addAttribute("source", URIUtil.toUnencodedString(artifactRepo));
-		addTask(mirror);
-		runAntTask();
-
-		File repo = new File(destinationRepo);
-
-		assertTrue(new File(repo, "plugins/org.eclipse.core.filebuffers_3.4.0.v20080603-2000.jar.pack.gz").exists());
-		assertTrue(new File(repo, "plugins/org.eclipse.osgi.services.source_3.1.200.v20071203.jar.pack.gz").exists());
-	}
-
 	/*
 	 * Modified from org.eclipse.equinox.p2.tests.mirror.ArtifactMirrorApplicationTest
 	 */
